/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.preference;

import org.eclipse.jface.preference.FieldEditorPreferencePage;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.preference.StringFieldEditor;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Group;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;

import com.clustercontrol.ClusterControlPlugin;
import com.clustercontrol.util.LoginManager;
import com.clustercontrol.util.Messages;

/**
 * ジョブ管理機能の設定ページクラスです。
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class ClusterControlCorePreferencePage extends FieldEditorPreferencePage
        implements IWorkbenchPreferencePage {

    /** EJB接続先URL */
    public static final String EJB_URL = LoginManager.KEY_EJB_URL;

    /**
     * 初期値が設定されたインスタンスを返します。
     */
    public ClusterControlCorePreferencePage() {
        super(GRID);
        this.setPreferenceStore(ClusterControlPlugin.getDefault()
                .getPreferenceStore());

        this.initializeDefaults();
    }

    /**
     * 初期値を設定します。
     */
    private void initializeDefaults() {
        IPreferenceStore store = this.getPreferenceStore();

        store.setDefault(EJB_URL, LoginManager.VALUE_EJB_URL);
    }

    /**
     * 設定フィールドを生成します。
     */
    public void createFieldEditors() {
        Composite parent = this.getFieldEditorParent();
        GridData gridData = null;
        // ジョブ[履歴]ビュー関連
        Group group = new Group(parent, SWT.SHADOW_NONE);
        gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        gridData.horizontalSpan = 10;
        gridData.verticalSpan = 10;
        group.setLayoutData(gridData);

        group.setText(Messages.getString("jboss.connection.setting"));

        // 接続先URL
        this.addField(new StringFieldEditor(EJB_URL, Messages
                .getString("connection.url"), group));
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.jface.preference.IPreferencePage#performOk()
     */
    public boolean performOk() {
        boolean result = super.performOk();

        //セッションに接続先URLを格納
        IPreferenceStore store = this.getPreferenceStore();
        store.getString(EJB_URL);

        return result;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IWorkbenchPreferencePage#init(org.eclipse.ui.IWorkbench)
     */
    public void init(IWorkbench workbench) {

    }
}