/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.ArrayList;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.jobmanagement.ejb.session.JobController;
import com.clustercontrol.jobmanagement.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;

/**
 * ジョブ[ファイル転送]ビューの一覧情報を取得するクラスです。
 * 
 * マネージャにSessionBean経由でアクセスし、ファイル転送一覧情報を取得する
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class GetForwardFile {
	
	/**
	 * マネージャにSessionBean経由でアクセスし、ファイル転送一覧情報を取得する
	 * 
	 * @param sessionId セッションID
	 * @param jobId ジョブID
	 * @return ファイル転送一覧情報（Objectの2次元配列）
	 * @see com.clustercontrol.jobmanagement.ejb.session.JobController
	 * @see com.clustercontrol.jobmanagement.util.EjbConnectionManager
	 * @see com.clustercontrol.jobmanagement.ejb.session.JobControllerBean#getForwardFileList(java.lang.String, java.lang.String)
	 */
	public ArrayList get(String sessionId, String jobId) {
		JobController job = 
			EjbConnectionManager.getConnectionManager().getJobController();
		
		ArrayList list = null;
		
		try {
			list = job.getForwardFileList(sessionId, jobId);
		} catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
				MessageDialog.openInformation(null, Messages.getString("message"),
						Messages.getString("message.accesscontrol.16"));
			}
		} catch (FinderException e) {
		} catch (NamingException e) {
		} catch (CreateException e) {
		}
		
		return list;
	}
}
