/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.factory;

import java.sql.Time;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collection;
import java.util.Date;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.accesscontrol.factory.AccessLock;
import com.clustercontrol.bean.JobConstant;
import com.clustercontrol.bean.JudgmentObjectConstant;
import com.clustercontrol.jobmanagement.bean.JobCommandInfo;
import com.clustercontrol.jobmanagement.bean.JobEndStatusInfo;
import com.clustercontrol.jobmanagement.bean.JobFileInfo;
import com.clustercontrol.jobmanagement.bean.JobInfo;
import com.clustercontrol.jobmanagement.bean.JobNotificationsInfo;
import com.clustercontrol.jobmanagement.bean.JobObjectInfo;
import com.clustercontrol.jobmanagement.bean.JobParameterInfo;
import com.clustercontrol.jobmanagement.bean.JobTreeItem;
import com.clustercontrol.jobmanagement.bean.JobWaitRuleInfo;
import com.clustercontrol.jobmanagement.ejb.entity.JobCommandMasterLocal;
import com.clustercontrol.jobmanagement.ejb.entity.JobCommandMasterUtil;
import com.clustercontrol.jobmanagement.ejb.entity.JobEndMasterLocal;
import com.clustercontrol.jobmanagement.ejb.entity.JobEndMasterUtil;
import com.clustercontrol.jobmanagement.ejb.entity.JobFileMasterLocal;
import com.clustercontrol.jobmanagement.ejb.entity.JobFileMasterUtil;
import com.clustercontrol.jobmanagement.ejb.entity.JobMasterLocal;
import com.clustercontrol.jobmanagement.ejb.entity.JobMasterUtil;
import com.clustercontrol.jobmanagement.ejb.entity.JobNoticeMasterLocal;
import com.clustercontrol.jobmanagement.ejb.entity.JobNoticeMasterUtil;
import com.clustercontrol.jobmanagement.ejb.entity.JobParamMasterLocal;
import com.clustercontrol.jobmanagement.ejb.entity.JobParamMasterUtil;
import com.clustercontrol.jobmanagement.ejb.entity.JobRelationMasterLocal;
import com.clustercontrol.jobmanagement.ejb.entity.JobRelationMasterUtil;
import com.clustercontrol.jobmanagement.ejb.entity.JobStartJobMasterLocal;
import com.clustercontrol.jobmanagement.ejb.entity.JobStartJobMasterUtil;
import com.clustercontrol.jobmanagement.ejb.entity.JobStartMasterLocal;
import com.clustercontrol.jobmanagement.ejb.entity.JobStartMasterUtil;
import com.clustercontrol.jobmanagement.ejb.entity.JobStartTimeMasterLocal;
import com.clustercontrol.jobmanagement.ejb.entity.JobStartTimeMasterUtil;

/**
 * ジョブツリー情報を登録するクラスです。
 *
 * @version 1.0.0
 * @since 1.0.0
 */
public class ModifyJob {
	/** ログ出力のインスタンス */
    protected static Log m_log = LogFactory.getLog( ModifyJob.class );
    
    /**
     * ジョブツリー情報を登録します。
	 * <p>
	 * <ol>
	 * <li>全ジョブマスタ情報を取得します。</li>
	 * <li>取得したジョブマスタ情報の数だけ以下の処理を行います</li>
	 *   <ol>
	 *   <li>ジョブリレーションマスタを削除します。</li>
	 *   <li>ジョブコマンドマスタを削除します。</li>
	 *   <li>ジョブファイル転送マスタを削除します。</li>
	 *     <ol>
	 *     <li>ジョブ待ち条件ジョブマスタを削除します。</li>
	 *     <li>ジョブ待ち条件時刻マスタを削除します。</li>
	 *     <li>ジョブ待ち条件マスタを削除します。</li>
	 *     </ol>
	 *   <li>ジョブ通知マスタを削除します。</li>
	 *   <li>ジョブ終了状態マスタを削除します。</li>
	 *   <li>ジョブ変数マスタを削除します。</li>
	 *   <li>ジョブマスタを削除します。</li>
	 *   </ol>
	 *   <li>ジョブツリー情報を基に、ジョブマスタを作成します。</li>
	 * </ol>
     * 
     * @param item ジョブツリー情報
     * @param user ユーザID
     * @throws FinderException
     * @throws NamingException
     * @throws RemoveException
     * @throws CreateException
     * 
     * @see com.clustercontrol.jobmanagement.factory.ModifyJob#createJobMaster(JobTreeItem, String)
     */
    public void registerJob(JobTreeItem item, String user) throws FinderException, NamingException, RemoveException, CreateException {
    	int msec = Calendar.getInstance().get(Calendar.MILLISECOND);
    	m_log.debug("registerJob(): start : " + msec);
    	m_log.debug("registerJob(): AccessLock Start : " + msec);
    	
    	//アクセスロック
    	AccessLock.lock(AccessLock.JOB);

    	m_log.debug("registerJob(): AccessLock End : " + msec);
    	
    	//全ジョブを取得する
        Collection jobList = JobMasterUtil.getLocalHome().findAll();
        if(jobList != null && jobList.size() > 0){
            Object[] jobArray = jobList.toArray();
            for(int i = 0; i < jobArray.length; i++){
                JobMasterLocal job = (JobMasterLocal)jobArray[i];
                
                //リレーションを削除
                JobRelationMasterLocal relation = job.getJobRelationMaster();
                if(relation != null){
                    relation.remove();
                }
                //コマンドを削除
                JobCommandMasterLocal command = job.getJobCommandMaster();
                if(command != null){
                    command.remove();
                }
                //ファイル転送を削除
                JobFileMasterLocal file = job.getJobFileMaster();
                if(file != null){
                	file.remove();
                }
                //開始条件(待ち条件)を削除
                JobStartMasterLocal start = job.getJobStartMaster();
                if(start != null){
	                //開始条件(待ち条件ジョブ)を削除
	                Collection collection = start.getJobStartJobMaster();
	                if(collection != null && collection.size() > 0){
	                    Object[] startJobArray = collection.toArray();
	                    for(int j = 0; j < startJobArray.length; j++){
	                    	JobStartJobMasterLocal startJob = (JobStartJobMasterLocal)startJobArray[j];
	                        if(startJob != null){
	                        	startJob.remove();
	                        }
	                    }
	                }
	                //開始条件(待ち条件時刻)を削除
	                JobStartTimeMasterLocal startTime = start.getJobStartTimeMaster();
	                if(startTime != null){
	                	startTime.remove();
	                }
                    start.remove();
                }
                //通知メッセージを削除
                Collection collection = job.getJobNoticeMaster();
                if(collection != null && collection.size() > 0){
                    Object[] noticeArray = collection.toArray();
                    for(int j = 0; j < noticeArray.length; j++){
                        JobNoticeMasterLocal notice = (JobNoticeMasterLocal)noticeArray[j];
                        if(notice != null){
                            notice.remove();
                        }
                    }
                }
                //終了状態を削除
                collection = job.getJobEndMaster();
                if(collection != null && collection.size() > 0){
                    Object[] endArray = collection.toArray();
                    for(int j = 0; j < endArray.length; j++){
                        JobEndMasterLocal end = (JobEndMasterLocal)endArray[j];
                        if(end != null){
                            end.remove();
                        }
                    }
                }
                //パラメータを削除
                collection = job.getJobParamMaster();
                if(collection != null && collection.size() > 0){
                    Object[] paramArray = collection.toArray();
                    for(int j = 0; j < paramArray.length; j++){
                    	JobParamMasterLocal param = (JobParamMasterLocal)paramArray[j];
                        if(param != null){
                        	param.remove();
                        }
                    }
                }
                
                //ジョブを削除
                job.remove();
            }
        }
        
        //ジョブを登録する
        JobTreeItem[] jobItems = item.getChildren(0).getChildren();
        for(int i = 0; i < jobItems.length; i++){
            //ジョブマスタ作成
            createJobMaster(jobItems[i], user);
        }
        
        m_log.debug("registerJob(): End : " + msec);
    }
    
    /**
     * ジョブマスタを作成します。
     * 再帰呼び出しを行います。
	 * <p>
	 * <ol>
	 * <li>ジョブツリー情報を基に、ジョブマスタを作成します。</li>
	 * <li>ジョブツリー情報の配下のジョブツリー情報を取得します。</li>
	 * <li>取得した配下のジョブツリー情報の数、以下の処理を行います。</li>
	 *   <ol>
	 *   <li>ジョブツリー情報を基に、ジョブマスタを作成します。</li>
	 *   </ol>
	 * </ol>
     * 
     * @param item ジョブツリー情報
     * @param user ユーザID
     * @throws CreateException
     * @throws NamingException
     * 
     * @see com.clustercontrol.jobmanagement.factory.ModifyJob#createJobMasterData(JobTreeItem, String)
     */
    protected void createJobMaster(JobTreeItem item, String user) throws CreateException, NamingException {
        
        //ジョブマスタデータ作成
        createJobMasterData(item, user);
        
        //子JobTreeItemを取得
        JobTreeItem[] childrens = item.getChildren();
        for(int i = 0; i < childrens.length; i++){
            //ジョブマスタ作成
            createJobMaster(childrens[i], user);
        }
    }
    
    /**
     * ジョブマスタを作成します。
	 * <p>
	 * <ol>
	 * <li>ジョブツリー情報を基に、ジョブマスタを作成します。</li>
	 * <li>ジョブツリー情報を基に、ジョブリレーションマスタを作成します。</li>
	 * <li>ジョブツリー情報を基に、ジョブ待ち条件マスタを作成します。</li>
	 * <li>ジョブツリー情報を基に、ジョブ待ち条件ジョブマスタを作成します。</li>
	 * <li>ジョブツリー情報を基に、ジョブ待ち条件時刻マスタを作成します。</li>
	 * <li>ジョブツリー情報を基に、ジョブコマンドマスタを作成します。</li>
	 * <li>ジョブツリー情報を基に、ジョブファイル転送マスタを作成します。</li>
	 * <li>ジョブツリー情報を基に、ジョブ通知マスタを作成します。</li>
	 * <li>ジョブツリー情報を基に、ジョブ終了状態マスタを作成します。</li>
	 * <li>ジョブツリー情報を基に、ジョブ変数マスタを作成します。</li>
	 * </ol>
     * 
     * @param item ジョブツリー情報
     * @param user ユーザID
     * @throws CreateException
     * @throws NamingException
     */
    protected void createJobMasterData(JobTreeItem item, String user) throws CreateException, NamingException {
        JobInfo info = item.getData();
        
        if(info.getCreateUser() == null)
        	info.setCreateUser(user);
        
        if(info.getCreateTime() == null)
        	info.setCreateTime(new Date());
        
        //ジョブ作成
        JobMasterUtil.getLocalHome().create(
                info.getId(), 
                info.getName(), 
                info.getDescription(), 
                new Integer(info.getType()), 
                info.getCreateTime(), 
                new Date(), 
                info.getCreateUser(), 
                user);
        
        String parentId = null;
        if(info.getType() == JobConstant.TYPE_JOBUNIT){
            parentId = "TOP";
        }
        else{
            parentId = item.getParent().getData().getId();
        }
        
        //ジョブリレーション作成
        JobRelationMasterUtil.getLocalHome().create(
                info.getId(), 
                parentId);
        
        //待ち条件作成
        if(info.getWaitRule() instanceof JobWaitRuleInfo){
        	Time startDelayTime = null;
        	Time endDelayTime = null;
        	if(info.getWaitRule().getStart_delay_time_value() instanceof Date)
        		startDelayTime = new Time(info.getWaitRule().getStart_delay_time_value().getTime());
        	if(info.getWaitRule().getEnd_delay_time_value() instanceof Date)
        		endDelayTime = new Time(info.getWaitRule().getEnd_delay_time_value().getTime());
        			
            JobStartMasterUtil.getLocalHome().create(
                    info.getId(), 
                    new Integer(info.getWaitRule().getCondition()), 
                    new Integer(info.getWaitRule().getSuspend()), 
                    new Integer(info.getWaitRule().getSkip()), 
                    new Integer(info.getWaitRule().getSkipEndStatus()), 
                    new Integer(info.getWaitRule().getSkipEndValue()), 
                    new Integer(info.getWaitRule().getEndCondition()), 
                    new Integer(info.getWaitRule().getEndStatus()), 
                    new Integer(info.getWaitRule().getEndValue()), 
                    new Integer(info.getWaitRule().getCalendar()), 
                    info.getWaitRule().getCalendarId(), 
                    new Integer(info.getWaitRule().getCalendarEndValue()), 
                    new Integer(info.getWaitRule().getStart_delay()), 
                    new Integer(info.getWaitRule().getStart_delay_session()), 
                    new Integer(info.getWaitRule().getStart_delay_session_value()), 
                    new Integer(info.getWaitRule().getStart_delay_time()), 
                    startDelayTime, 
                    new Integer(info.getWaitRule().getStart_delay_condition_type()), 
                    new Integer(info.getWaitRule().getStart_delay_notify()), 
                    new Integer(info.getWaitRule().getStart_delay_notify_priority()), 
                    new Integer(info.getWaitRule().getStart_delay_operation()), 
                    new Integer(info.getWaitRule().getStart_delay_operation_type()), 
                    new Integer(info.getWaitRule().getStart_delay_operation_end_value()), 
                    new Integer(info.getWaitRule().getEnd_delay()), 
                    new Integer(info.getWaitRule().getEnd_delay_session()), 
                    new Integer(info.getWaitRule().getEnd_delay_session_value()), 
                    new Integer(info.getWaitRule().getEnd_delay_job()), 
                    new Integer(info.getWaitRule().getEnd_delay_job_value()), 
                    new Integer(info.getWaitRule().getEnd_delay_time()), 
                    endDelayTime, 
                    new Integer(info.getWaitRule().getEnd_delay_condition_type()), 
                    new Integer(info.getWaitRule().getEnd_delay_notify()), 
                    new Integer(info.getWaitRule().getEnd_delay_notify_priority()), 
                    new Integer(info.getWaitRule().getEnd_delay_operation()), 
                    new Integer(info.getWaitRule().getEnd_delay_operation_type()), 
                    new Integer(info.getWaitRule().getEnd_delay_operation_end_value()));
            
            if(info.getWaitRule().getObject() instanceof ArrayList){
                for(int i = 0; i < info.getWaitRule().getObject().size(); i++){
                    if(info.getWaitRule().getObject().get(i) instanceof JobObjectInfo){
                        JobObjectInfo objectInfo = 
                            (JobObjectInfo)info.getWaitRule().getObject().get(i);
                        
                        if(objectInfo.getType() == JudgmentObjectConstant.TYPE_JOB_END_STAUS){
                            JobStartJobMasterUtil.getLocalHome().create(
                                    info.getId(), 
                                    objectInfo.getJobId(), 
                                    new Integer(JudgmentObjectConstant.TYPE_JOB_END_STAUS), 
                                    new Integer(objectInfo.getValue()));
                        }
                        else if(objectInfo.getType() == JudgmentObjectConstant.TYPE_JOB_END_VALUE){
                            JobStartJobMasterUtil.getLocalHome().create(
                                    info.getId(), 
                                    objectInfo.getJobId(), 
                                    new Integer(JudgmentObjectConstant.TYPE_JOB_END_VALUE), 
                                    new Integer(objectInfo.getValue()));
                        }
                        else{
                            JobStartTimeMasterUtil.getLocalHome().create(
                                    info.getId(), 
                                    new Time(objectInfo.getTime().getTime()));
                        }
                    }
                }
            }
        }
        
        //実行コマンド作成
        if(info.getCommand() instanceof JobCommandInfo){
            JobCommandMasterUtil.getLocalHome().create(
                    info.getId(), 
                    info.getCommand().getFacilityID(), 
                    new Integer(info.getCommand().getProcessingMethod()), 
                    info.getCommand().getStartCommand(), 
                    info.getCommand().getStopCommand(), 
                    info.getCommand().getUser(), 
                    new Integer(info.getCommand().getErrorEndFlg()), 
                    new Integer(info.getCommand().getErrorEndValue()),
                    "", 
                    "");
        }
        
        //ファイル転送作成
        if(info.getFile() instanceof JobFileInfo){
            JobFileMasterUtil.getLocalHome().create(
                    info.getId(), 
                    new Integer(info.getFile().getProcessingMethod()), 
                    info.getFile().getSrcFacilityID(), 
                    info.getFile().getDestFacilityID(), 
                    info.getFile().getSrcFile(), 
                    info.getFile().getSrcWorkDir(), 
                    info.getFile().getDestDirectory(), 
                    info.getFile().getDestWorkDir(), 
                    new Integer(info.getFile().getCompressionFlg()), 
                    new Integer(info.getFile().getCheckFlg()), 
                    info.getFile().getUser());
        }
        
        //通知メッセージを取得
        if(info.getNotifications() instanceof ArrayList){
            for(int i = 0; i < info.getNotifications().size(); i++){
                if(info.getNotifications().get(i) instanceof JobNotificationsInfo){
                    JobNotificationsInfo notificationsInfo = 
                        (JobNotificationsInfo)info.getNotifications().get(i);
                    
                    JobNoticeMasterUtil.getLocalHome().create(
                            info.getId(), 
                            new Integer(notificationsInfo.getType()), 
                            new Integer(notificationsInfo.getPriority()), 
                            notificationsInfo.getNotify_id());
                }
            }
        }
        
        //終了状態を取得
        if(info.getEndStatus() instanceof ArrayList){
            for(int i = 0; i < info.getEndStatus().size(); i++){
                if(info.getEndStatus().get(i) instanceof JobEndStatusInfo){
                    JobEndStatusInfo endInfo = 
                        (JobEndStatusInfo)info.getEndStatus().get(i);
                    
                    JobEndMasterUtil.getLocalHome().create(
                            info.getId(), 
                            new Integer(endInfo.getType()), 
                            new Integer(endInfo.getValue()), 
                            new Integer(endInfo.getStartRangeValue()), 
                            new Integer(endInfo.getEndRangeValue()));
                }
            }
        }
        
        //パラメータを取得
        if(info.getParam() instanceof ArrayList){
            for(int i = 0; i < info.getParam().size(); i++){
                if(info.getParam().get(i) instanceof JobParameterInfo){
                	JobParameterInfo paramInfo = 
                        (JobParameterInfo)info.getParam().get(i);
                    
                    JobParamMasterUtil.getLocalHome().create(
                            info.getId(), 
                            paramInfo.getParamId(), 
                            new Integer(paramInfo.getType()), 
                            paramInfo.getDescription(), 
                            paramInfo.getValue());
                }
            }
        }
    }
}
