/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.view.action;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.PlatformUI;

import com.clustercontrol.bean.JobConstant;
import com.clustercontrol.jobmanagement.bean.JobInfo;
import com.clustercontrol.jobmanagement.bean.JobTreeItem;
import com.clustercontrol.jobmanagement.bean.JobWaitRuleInfo;
import com.clustercontrol.jobmanagement.composite.JobTreeComposite;
import com.clustercontrol.jobmanagement.dialog.JobDialog;
import com.clustercontrol.jobmanagement.view.JobListView;

/**
 * ファイル転送ジョブ追加アクションクラス
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class CreateFileJobAction implements IViewActionDelegate {
    public static final String ID = "com.clustercontrol.jobmanagement.view.action.CreateFileJobAction";

    protected IViewPart m_view;

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
     */
    public void init(IViewPart view) {
        m_view = view;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
     */
    public void run(IAction action) {
        JobTreeItem item = null;
        JobTreeItem parent = null;

        if (m_view instanceof JobListView) {
            JobListView view = (JobListView) m_view
                    .getAdapter(JobListView.class);
            JobTreeComposite tree = view.getJobTreeComposite();
            parent = view.getSelectJobTreeItem();

            if (parent instanceof JobTreeItem) {
                item = new JobTreeItem(
                        new JobInfo("", "", JobConstant.TYPE_FILEJOB));
                item.getData().setUpdate(true);
                item.getData().setWaitRule(new JobWaitRuleInfo());
                parent.addChildren(item);

                JobDialog dialog = new JobDialog(
                		PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell(), 
                		false);
                dialog.setJobTreeItem(item);

                //ダイアログ表示
                if (dialog.open() == IDialogConstants.OK_ID) {
                    view.setUpdate(true);
                } else {
                    parent.removeChildren(item);
                }
                tree.getTreeViewer().refresh(parent);
                tree.getTreeViewer().setSelection(
                        new StructuredSelection(parent), true);
            }
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
     *      org.eclipse.jface.viewers.ISelection)
     */
    public void selectionChanged(IAction action, ISelection selection) {

    }
}