/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 */

package com.clustercontrol.performanceMGR.ejb.bmp;

import java.rmi.RemoteException;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.Iterator;
import java.util.List;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.EntityBean;
import javax.ejb.EntityContext;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.rmi.PortableRemoteObject;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.quartz.CronTrigger;
import org.quartz.JobDetail;
import org.quartz.Scheduler;
import org.quartz.SchedulerException;
import org.quartz.Trigger;

import com.clustercontrol.bean.EndStatusConstant;
import com.clustercontrol.bean.FacilityTreeItem;
import com.clustercontrol.performanceMGR.bean.CollectedDataInfo;
import com.clustercontrol.performanceMGR.bean.CollectorItemInfo;
import com.clustercontrol.performanceMGR.bean.CollectorRunStatus;
import com.clustercontrol.performanceMGR.bean.CollectorType;
import com.clustercontrol.performanceMGR.bean.DeviceData;
import com.clustercontrol.performanceMGR.bean.EventCode;
import com.clustercontrol.performanceMGR.bean.OIDInfo;
import com.clustercontrol.performanceMGR.bean.QuartzConstant;
import com.clustercontrol.performanceMGR.bean.ScopeTree;
import com.clustercontrol.performanceMGR.bean.SnmpPollerConstant;
import com.clustercontrol.performanceMGR.dao.CalculatedDataDAO;
import com.clustercontrol.performanceMGR.dao.CollectorItemDAO;
import com.clustercontrol.performanceMGR.dao.DeviceDAO;
import com.clustercontrol.performanceMGR.dao.RecordDataDAO;
import com.clustercontrol.performanceMGR.dao.ScopeRelationDAO;
import com.clustercontrol.performanceMGR.dao.ScopeSnapDAO;
import com.clustercontrol.performanceMGR.ejb.bmp.CollectorStatusLocal;
import com.clustercontrol.performanceMGR.ejb.bmp.CollectorStatusPK;
import com.clustercontrol.performanceMGR.ejb.bmp.CollectorStatusUtil;
import com.clustercontrol.performanceMGR.job.CollectJob;
import com.clustercontrol.performanceMGR.monitor.ejb.entity.MonitorPerfInfo;
import com.clustercontrol.performanceMGR.monitor.ejb.entity.MonitorPerfInfoHome;
import com.clustercontrol.performanceMGR.monitor.factory.RunMonitorPerformance2;
import com.clustercontrol.performanceMGR.util.CalculationMethod;
import com.clustercontrol.performanceMGR.util.FacilityTreeDB;
import com.clustercontrol.performanceMGR.util.JNDIConnectionManager;
import com.clustercontrol.performanceMGR.util.Repository;
import com.clustercontrol.snmppoller.SnmpSharedTable;
import com.clustercontrol.snmppoller.bean.PollingConfig;
import com.clustercontrol.util.apllog.AplLogger;

/**
 * @ejb.bean name="Collector"
 *           display-name="Name for Collector"
 *           description="Description for Collector"
 *           jndi-name="Collector"
 *           type="BMP"
 *           view-type="both"
 * 
 * @jboss.depends name="jboss.jca:service=DataSourceBinding,name=HinemosDS"
 * 
 * @ejb.permission
 *     unchecked="true"
 * 
 * @ejb.data-object name="RecordCollectorData"
 *           
 * @ejb.dao
 *  class="com.clustercontrol.performanceMGR.ejb.bmp.CollectorDAO" 
 *  impl-class="com.clustercontrol.performanceMGR.dao.CollectorDAOImpl"
 *  
 * @jboss.container-configuration name="Collector Configuration"
 */
public class CollectorBean implements EntityBean {
//	public class CollectorBean implements EntityBean, TimedObject {
	// ログ出力用オブジェクト
	protected static Log m_log = LogFactory.getLog(CollectorBean.class);
	
	// 計算済み性能値を格納するDBへのアクセスオブジェクト
//	private CalculatedDataDAO m_dao;
	
	// 寿命の最大値(この値を越える回数参照がない場合は停止すべきと判断される)
	private final int MAX_LIFECOUNT = 2;  
	private int lifetimeCounter;    // 収集が終了するまでのカウンタ
	// 停止は外から remove()メソッドを呼び出すことで行う。
	// Bean が自分自身で停止することはない。
	
	private int collectorType;      // 収集種別(リアルタイム/実績/閾値監視)
	
	// 永続化する変数
	private String collectorID = null; // 収集ID
	private int interval;              // 収集間隔
	private String facilityID;         // 収集対象スコープ
	private ScopeTree scopeTree;       // 性能値算出用のスコープツリー情報
	private CollectorItemInfo[] items; // 収集項目のリスト（収集項目数分確保）
	
	private String label;
	private long startTime;
	private long stopTime;             // 収集終了時刻
	private String scopePath;
	private int period;
	private int presavePeriod;
	
	private OIDInfo[] targetOID;       // 収集対象のOIDの情報
	
	protected EntityContext entityCtx;  // Entyty Context
	
	public CollectorBean() {
		super();
	}

	/**
	 * EntityBeanを生成する際にコンテナから呼ばれます。
	 * @param data　収集設定の一意識別子pkオブジェクト
	 * 	 * <!-- begin-user-doc -->
	 * The  ejbCreate method.
	 * <!-- end-user-doc -->
	 *
	 * <!-- begin-xdoclet-definition --> 
	 * @ejb.create-method 
	 * <!-- end-xdoclet-definition --> 
	 * @generated
	 */
	public CollectorPK ejbCreate(RecordCollectorData data, List itemList)
	throws CreateException {
		m_log.debug("ejbCreate() start : " + data.getCollectorID());
		
//		m_dao = new CalculatedDataDAO();
		
		this.items = (CollectorItemInfo[])itemList.toArray(new CollectorItemInfo[itemList.size()]);
		setCollectorID(data.getCollectorID());
		setCollectorType(data.getCollectorType());
		setFacilityID(data.getFacilityID());
		setInterval(data.getInterval());
		setLabel(data.getLabel());
		setPeriod(data.getPeriod());
		setScopePath(data.getScopePath());
		setPresavePeriod(data.getPresavePeriod());
		// ファシリティツリー情報の設定は、ここでは行わずに ejbPostCreate() で実行する
		
		m_log.debug("ejbCreate() e : " + data.getCollectorID());
		
		return new CollectorPK(data.getCollectorID());
	}
	
	/**
	 * EntityBeanを生成直後にコンテナから呼ばれます。
	 * 
	 * 収集項目をDBに書き込みます。
	 * 
	 * @param pk 収集設定の一意識別子pkオブジェクト
	 */
	public void ejbPostCreate(RecordCollectorData data, List itemList)
	throws javax.ejb.CreateException {
		m_log.debug("ejbPostCreate()  Collector Type : " + collectorType);
		
		Repository repository = new Repository();
		
		// リポジトリからツリー情報を取得しScopeTreeオブジェクトに設定
		FacilityTreeItem facilityTree = repository.getFacilityTree(facilityID);
		scopeTree = new ScopeTree(facilityTree);
		
		// スコープのフルパスを設定
		setScopePath(repository.getFacilityPath(facilityID));
		
		// 実績収集の場合はファシリティツリー情報をDBに格納する
		if(collectorType == CollectorType.RECORD){
			// ツリー情報をDBに書き込む
			new FacilityTreeDB().insertFacilityTree(collectorID, facilityTree);
			
			// リポジトリからデバイス情報を取得
			List deviceList = repository.getDeviceList(facilityID);
			
			// デバイス情報用のDAOを生成
			DeviceDAO dvdao = new DeviceDAO();
			
			Iterator itr = deviceList.iterator();
			while(itr.hasNext()){		
				// デバイス情報をDBに書き込む
				dvdao.insertDeviceData(collectorID, (DeviceData)itr.next());
			}
		}
		
		// 収集項目用のDAOを生成
		CollectorItemDAO cidao = new CollectorItemDAO();
		
		for(int i=0; i<items.length; i++){
			// リアルタイム収集の場合は、設定時に収集IDがセットされないためここでセットする
			items[i].setCollectorID(collectorID);
			
			// 収集項目をDBに書き込む
			cidao.registCollectorItem(items[i]);
		}
		
		// 状態を保持するEntityBeanを生成
		try {
			CollectorStatusUtil.getLocalHome().create(new CollectorStatusPK(collectorID));
		} catch (NamingException e) {
			m_log.error(e);
			throw new EJBException(e);
		}
	}
	
	/**
	 * DBから収集項目の情報を取得し設定します。
	 *
	 */
	public void setCollectorItems(String collectoId){
		// 収集項目用のDAOを生成
		CollectorItemDAO cidao = new CollectorItemDAO();
		
		Collection col = cidao.selectCollectorItemByCollectorID(collectoId);
		items = (CollectorItemInfo[])col.toArray(new CollectorItemInfo[col.size()]);
		
		// この収集で必要となる収集対象のOID情報を取得
		targetOID = CalculationMethod.getTargetOid(items);
	}
	
	/**
	 * プライマリキーをもとにEntityBeanを検索する際にコンテナから呼ばれます。
	 * @param pk 収集設定の一意識別子pk
	 * @return pk
	 **/
	public CollectorPK ejbFindByPrimaryKey(CollectorPK pk) throws FinderException {
		return pk; 
	}
	
	/**
	 * 収集種別で検索を行います。
	 *
	 * @param type 収集種別
	 * @return CollectorPK 収集設定の一意識別子pkオブジェクトのリスト
	 **/
	public Collection ejbFindByCollectorType(int type) throws FinderException { 
		m_log.debug("ejbFindByStatus() : Type = " + type);
		
		// ここでは何もせず、DAOの実装クラスに処理をまかせる
		return null; 
	}
	/*
	 * 動作中の無期限収集を取得します。
	 */
	public Collection ejbFindByPresave() throws FinderException{
		m_log.debug("ejbFindByPresave() : ");
		
		// ここでは何もせず、DAOの実装クラスに処理をまかせる
		return null; 
		
	}
	
	
	/**
	 * 全ての収集の検索を行います。
	 *
	 * @return CollectorPK 収集設定の一意識別子pkオブジェクトのリスト
	 **/
	public Collection ejbFindAll() throws FinderException { 
		m_log.debug("ejbFindAll() : ");
		
		// ここでは何もせず、DAOの実装クラスに処理をまかせる
		return null; 
	}
	
	public void ejbActivate() throws EJBException, RemoteException {
	}
	
	public void ejbLoad() throws EJBException, RemoteException {
		m_log.debug("ejbLoad() start : " + collectorID);
		
		m_log.debug("ejbLoad() end   : " + collectorID);
	}
	
	public void ejbPassivate() throws EJBException, RemoteException {
	}
	
	public void ejbRemove()
	throws RemoveException,	EJBException, RemoteException {
		m_log.debug("ejbRemove() start : " + collectorID);
		
		// Quartz に設定されているジョブを削除する
		deleteJob();
		
		// 状態を保持するEntityBeanを削除
		try {
			CollectorStatusUtil.getLocalHome().remove(new CollectorStatusPK(collectorID));
		} catch (NamingException e) {
			m_log.error(e);
			throw new EJBException(e);
		}
		
		// この収集IDに関連する収集項目を削除
		CollectorItemDAO cidao = new CollectorItemDAO();
		cidao.deleteCollectorItemByCollectorID(collectorID);
		
		// この収集IDに関連するデバイス情報を削除
		DeviceDAO dvdao = new DeviceDAO();
		dvdao.deleteDeviceDataByCollectorID(collectorID);
		
		// ファシリティツリー情報を削除
		ScopeRelationDAO srdao = new ScopeRelationDAO();
		ScopeSnapDAO ssdao = new ScopeSnapDAO();
		srdao.deleteScopeRelationByCollectorID(collectorID); // スコープの関係を削除
		ssdao.deleteScopeSnapByCollectorID(collectorID); // スコープ情報を削除	
		
		// MIBのデータを削除
		RecordDataDAO dataDao = new RecordDataDAO();
		dataDao.deleteRecordData(collectorID);
		
		// 性能値データを削除
		CalculatedDataDAO calDao = new CalculatedDataDAO();
		calDao.delete(collectorID);
		
		m_log.debug("ejbRemove() end   : " + collectorID);
	}
	
	public void ejbStore() throws EJBException, RemoteException {
		// ここでは何もせず、DAOの実装クラスに処理をまかせる
	}
	
	public void setEntityContext(EntityContext ctx)
	throws EJBException, RemoteException {
		entityCtx = ctx;
	}
	
	public void unsetEntityContext() throws EJBException, RemoteException {
	}
	
	/**
	 * 収集設定を取得します。
	 * @return 収集設定情報
	 * 
	 * @ejb.interface-method
	 *  view-type="both"
	 */
	public RecordCollectorData getRecordColletorData(){
		m_log.debug("getRecordColletorData() strat : ");
		
		RecordCollectorData data =  new RecordCollectorData();
		
		data.setCollectorID(getCollectorID());
		data.setCollectorType(getCollectorType());
		data.setFacilityID(getFacilityID());
		data.setInterval(getInterval());
		data.setCount(getCount());
		data.setLabel(getLabel());
//		data.setMonitorFlag(isMonitorFlag());
		data.setStatus(getStatus());
		data.setPeriod(getPeriod());
		data.setScopePath(getScopePath());
		data.setStartDate(getStartDate());
		data.setStopDate(getStopDate());
		data.setFacilityTree(getFacilityTree());
		data.setRealCollectPeriod(getRealCollectPeriod());
		data.setEndStatus(getEndStatus());
		data.setPresavePeriod(getPresavePeriod());
		m_log.debug("getRecordColletorData() end   : ");
		return data;
	}
	
	/**
	 * 収集を開始します。
	 * @throws NamingException 
	 * 
	 * @ejb.interface-method
	 *	view-type="both" 
	 */
	public void startCollect() throws NamingException{
		m_log.debug("startCollect() start : " + collectorID + " " + collectorType);
		
		setCollectorType(collectorType);
		
		// SNMPポーリングをスタートさせる
		startPoller();
		
		// この収集で必要となる収集対象のOID情報を取得
		this.targetOID = CalculationMethod.getTargetOid(this.items);
		
		// 収集終了予定時刻を設定
		if(period == -1){
			this.stopTime = Long.MAX_VALUE;
		} else {
			this.stopTime = System.currentTimeMillis() + period * 60 * 1000l;
		}
		
		// Quartz にスケジュールを設定
		scheduleJob();
		
		// 収集開始時刻を設定
		setStartTime(System.currentTimeMillis());
		
		// すぐに getValue() が呼ばれた場合にそなえる
		scopeTree.fetchMibValue(this.facilityID, this.targetOID, this.interval);
		
		m_log.debug("startCollect() end   : " + collectorID + " " + collectorType);
	}
	
	
	/**
	 * 収集を再開します。
	 * @throws NamingException 
	 * 
	 * @ejb.interface-method
	 *	view-type="both" 
	 * 
	 * @return 収集を再開した場合は true 再開しなかった場合は false を返す
	 * @throws NamingException
	 */
	public boolean restartCollect() throws NamingException {
		m_log.debug("restartCollect() start : " + collectorID + " " + collectorType);
		
		boolean isRunning = false;
		
		// 収集中かどうかを調べる
		if(getStatus() == CollectorRunStatus.RUNNING){
			isRunning = true;
		}
		
		boolean isRestart = false;
		
		// 収集終了時刻を設定
		if(period == -1){
			this.stopTime = Long.MAX_VALUE;
		}
		
		// 現在時刻よりも収集終了時刻のほうが大きい場合は再度収集を開始する
		if(System.currentTimeMillis() < stopTime){
			// SNMPポーリングをスタートさせる
			startPoller();
			
			// この収集で必要となる収集対象のOID情報を取得
			this.targetOID = CalculationMethod.getTargetOid(this.items);
			
			// すぐに getValue() が呼ばれた場合にそなえる
			scopeTree.fetchMibValue(this.facilityID, this.targetOID, this.interval);
			
			// Quartz にスケジュールを設定
			scheduleJob();
			
			isRestart = true;

			if(collectorType == CollectorType.RECORD){
				// アプリケーションログを出力
				// 収集IDをログ情報としてログを出力する
				String[] messages = { "CollectorID : " + collectorID };
				outputLog(EventCode.WarningRestart, messages);
			} else if (collectorType == CollectorType.MONITOR){
				// アプリケーションログを出力
				// 監視IDをログ情報としてログを出力する
				String[] messages = { "MonitorID : " + label };
				outputLog(EventCode.WarningRestart, messages);
			}
			
			// 既に収集中であったもので再実行したものはエラー状態を変更しない
			if(!isRunning){
				setErrorStatus(EndStatusConstant.TYPE_WARNING);
			}
		}
		
		m_log.debug("restartCollect() end   : " + collectorID + " " + collectorType);
		
		return isRestart;
	}
	
	/**
	 * SNMPポーラーを起動する
	 * @throws NamingException 
	 */
	private void startPoller() throws NamingException {
		if(scopeTree == null || facilityID == null){
			// エラー処理
			return;
		}
		
		// 対象ファシリティに含まれるノードのリストを取得
		String[] nodeIDList = scopeTree.getNodeIDList(facilityID);
		
		// SNMP収集値の共有テーブルをルックアップします。
		SnmpSharedTable sst = null;
		
		InitialContext iniCtx = JNDIConnectionManager.getInitialContext();
		Object obj = iniCtx.lookup(SnmpPollerConstant.JNDI_NAME);
		
		// 取得したオブジェクトをキャストします。
		sst = (SnmpSharedTable)PortableRemoteObject.narrow(obj, SnmpSharedTable.class);
		
		// SNMPポーラーのスケジュールを設定
		if(collectorType != CollectorType.REALTIME){
			// リアルタイム収集以外の場合は、ポーリング開始から1秒待ってから
			// 制御がもどるように呼び出す
			// 1秒以内にSNMPのポーリングで値が取得できれば、初回収集も値が算出可能となる
			m_log.debug("polling start . wait time 1000ms");
			sst.setPollingSchedule(nodeIDList, interval, 1000);
		} else {
			m_log.debug("polling start . wait time 0ms");
			sst.setPollingSchedule(nodeIDList, interval, 0);
		}
	}
	
	/**
	 * 値を取得します。(他のgetValueメソッドから呼ばれる大元となるメソッド)
	 * 
	 * @ejb.interface-method
	 *	view-type="both" 
	 **/
	public CollectedDataInfo getValue(String facilityId, String itemCode, int deviceIndex){
		// 生存期間カウンタをリセット
		resetLifetimeCounter();
		
		CollectedDataInfo data = scopeTree.getValue(facilityId, itemCode, deviceIndex);
		
		// リアルタイム収集で値が取得できなかった場合は前の値を返す
		if((collectorType == CollectorType.REALTIME) && Double.isNaN(data.getValue())){
			data = scopeTree.getTempValue(facilityId, itemCode, deviceIndex);
		}
		
		return data;
	}
	
	/**
	 * 値を取得します。
	 * 
	 * @ejb.interface-method
	 *	view-type="both" 
	 **/
	public CollectedDataInfo getValue(String facilityId, int itemId){
		for(int i=0; i<items.length; i++){
			if(items[i].getCollectorItemID() == itemId){
				return getValue(
						facilityId, 
						items[i].getCollectorItemCode(), 
						items[i].getDeviceIndex()
				);
			}
		}
		
		// 指定の収集項目IDに一致する収集項目が見付からなかった場合
		return null;
	}
	
	/**
	 * 値を取得します。
	 * 
	 * @ejb.interface-method
	 *	view-type="both" 
	 **/
	public CollectedDataInfo[] getValueAll(String facilityId){
		CollectedDataInfo[] dataList = new CollectedDataInfo[items.length];
		
		for(int i=0; i<items.length; i++){
			dataList[i] = getValue(
					facilityId, 
					items[i].getCollectorItemCode(), 
					items[i].getDeviceIndex()
			);
			
		}
		
		return dataList;
	}
	
	/**
	 * 指定スコープのサブスコープのファシリティの値を取得します。
	 * 
	 * @ejb.interface-method
	 *	view-type="both" 
	 **/
	public List getSubScopeValues(String facilityId, String itemCode, int deviceIndex){
		ArrayList ret = new ArrayList();		
		String[] subScopeFids = scopeTree.getSubScopeIDList(facilityId);
		
		for(int i=0; i<subScopeFids.length; i++){
			ret.add(getValue(subScopeFids[i], itemCode, deviceIndex));
		}
		
		return ret;
	}
	
	/**
	 * 指定スコープのサブスコープのファシリティの値を取得します。
	 * 
	 * @ejb.interface-method
	 *	view-type="both" 
	 **/
	public List getSubScopeValues(String facilityId, int itemId){
		for(int i=0; i<items.length; i++){
			if(items[i].getCollectorItemID() == itemId){
				return getSubScopeValues(
						facilityId, 
						items[i].getCollectorItemCode(), 
						items[i].getDeviceIndex()
				);
			}
		}
		
		// 指定の収集項目IDに一致する収集項目が見付からなかった場合
		return null;
	}
	
	/**
	 * 収集を終了します。
	 * 
	 * @ejb.interface-method
	 *	view-type="both" 
	 **/
	public void stopCollect(){
		m_log.debug("stopCollect() start : " + collectorID);
		
		// Quartz に設定されているジョブを削除する
		deleteJob();
		
		// 収集終了時刻を設定
		setStopTime(System.currentTimeMillis());
		
		m_log.debug("stopCollect() end   : " + collectorID);
	}	
	
	/**
	 * 収集スケジュールをQuartzに設定する
	 * @throws NamingException 
	 */
	private void scheduleJob() throws NamingException {
		m_log.debug("scheduleJob()  Group : "  + QuartzConstant.GROUP_COLLECT + " : " + collectorID + " : " + interval);
		
		//JobDetail作成
		JobDetail job = new JobDetail(
				collectorID, 
				QuartzConstant.GROUP_COLLECT, 
				CollectJob.class);
		
		//ジョブ完了時に削除されないようにする
		job.setDurability(true);
		
		//JobDetailに呼び出すメソッドの引数を設定
		job.getJobDataMap().put("pk", new CollectorPK(collectorID));
		job.getJobDataMap().put("type", collectorType);
		
		//CronTriggerを作成
		CronTrigger cronTrigger = new CronTrigger(collectorID, QuartzConstant.GROUP_COLLECT);
		
		try {
			String cronString = PollingConfig.parseCronExpression(interval);
			
			cronString = "0 */10 * * * ? *";
			
			if(interval < 60){  // 秒単位の場合
				cronString = "*/" + interval + " * * * * ? *";
			} else if (60 <= interval && interval < 3600){  // 分単位の場合
				cronString = "0 */" + interval/60 + " * * * ? *";
			} else if (3600 <= interval){  // 時間単位の場合
				cronString = "0 0 */" + interval/3600 + " * * ? *";
			} else {
				String message = "サポートしていない収集間隔です";
				throw new EJBException(message);
			}
			
			cronTrigger.setCronExpression(cronString);
			cronTrigger.setEndTime(new Date(stopTime));
		} catch (ParseException e) {
			m_log.error(e);
		} catch (IllegalArgumentException e){
			// CronTriggerクラスのsetEndTime()で 
			// end time よりも start time のほうが大きい場合throwされる
			m_log.error(e);
			
			// Quartzを起動する必要がないのでこのまま処理を終了する
			return;
		}
		
		//QuartzのSchedulerをルックアップ
		InitialContext iniCtx = JNDIConnectionManager.getInitialContext();
		Scheduler scheduler = (Scheduler)iniCtx.lookup(QuartzConstant.QUARTZ_NAME);
		
		try {
			// 既に登録されているジョブを削除する(登録されていない場合は何もおこらない)
			scheduler.deleteJob(collectorID, QuartzConstant.GROUP_COLLECT);
			
			// ジョブを登録する
			scheduler.scheduleJob(job, cronTrigger);
		} catch (SchedulerException e) {
			m_log.error(e);
		}
	}
	
	/**
	 * 収集起動ジョブを一時停止します。
	 *
	 */
	private void pauseJob() {
		m_log.debug("pauseJob() start : " + collectorID);
		
		//QuartzのSchedulerをルックアップ
		try {
			InitialContext iniCtx = JNDIConnectionManager.getInitialContext();
			Scheduler scheduler = (Scheduler)iniCtx.lookup(QuartzConstant.QUARTZ_NAME);
			
			// 既に登録されているジョブを削除する(登録されていない場合は何もおこらない)
			scheduler.pauseJob(collectorID, QuartzConstant.GROUP_COLLECT);
		} catch (NamingException e) {
			throw new EJBException(e);
		} catch (SchedulerException e) {
			m_log.error(e);
		}
		m_log.debug("pauseJob() end   : " + collectorID);
	}
	
	/**
	 * 収集起動ジョブを再開します。
	 *
	 */
	private void resumeJob() {
		m_log.debug("pauseJob() start : " + collectorID);
		
		//QuartzのSchedulerをルックアップ
		try {
			InitialContext iniCtx = JNDIConnectionManager.getInitialContext();
			Scheduler scheduler = (Scheduler)iniCtx.lookup(QuartzConstant.QUARTZ_NAME);
			
			// 既に登録されているジョブを削除する(登録されていない場合は何もおこらない)
			scheduler.resumeJob(collectorID, QuartzConstant.GROUP_COLLECT);
		} catch (NamingException e) {
			throw new EJBException(e);
		} catch (SchedulerException e) {
			m_log.error(e);
		}
		m_log.debug("pauseJob() end   : " + collectorID);
	}
	
	/**
	 * 収集起動ジョブを削除します。
	 *
	 */
	private void deleteJob() {
		m_log.debug("deleteJob() start : " + collectorID);
		
		//QuartzのSchedulerをルックアップ
		try {
			InitialContext iniCtx = JNDIConnectionManager.getInitialContext();
			Scheduler scheduler = (Scheduler)iniCtx.lookup(QuartzConstant.QUARTZ_NAME);
			
			// 既に登録されているジョブを削除する(登録されていない場合は何もおこらない)
			scheduler.deleteJob(collectorID, QuartzConstant.GROUP_COLLECT);
		} catch (NamingException e) {
			throw new EJBException(e);
		} catch (SchedulerException e) {
			m_log.error(e);
		}
		m_log.debug("deleteJob() end   : " + collectorID);
	}
	
	/**
	 * ポーラーのテーブルが保持するMIBの値を取得します。
	 * 
	 * @ejb.interface-method
	 *	view-type="both" 
	 */
	public void fetchMibValue(){
		m_log.debug("fetchMibValue() start : " + collectorID + "  " + collectorType);
		
		try{
			if(scopeTree == null || targetOID == null){
				m_log.debug("lost facility tree info.");
			} else {
				// MIB値を取得
				scopeTree.fetchMibValue(this.facilityID, this.targetOID, this.interval);
			}
			
			// 最終収集日時をDBに書き込みます
			setLastCollectDate(new Date(System.currentTimeMillis()));
			
			// 収集回数をDBに書き込みます
			setCount(getCount()+1);
			
			// 寿命カウンタを増加させます。
			lifetimeCounter++;
		} catch (Exception e) {
			m_log.error(e);
			// 状態を異常に変更
			this.setErrorStatus(EndStatusConstant.TYPE_ABNORMAL);
		}
		
		m_log.debug("fetchMibValue() end   : " + collectorID + "  " + collectorType);
	}
	
	/**
	 * 性能値を算出しDBに書き込みます。
	 * 
	 * @ejb.interface-method
	 *	view-type="both" 
	 */
	public void storeCalcValue(){
		m_log.debug("storeCalcValue() start : " + collectorID + "  " + collectorType);
		
		try{
			if(scopeTree == null || items == null || targetOID == null){
				m_log.debug("情報を失っています");
			} else {
				// MIB値を取得
				scopeTree.fetchMibValue(this.facilityID, this.targetOID, this.interval);
				
				// 全てのファシリティのIDを取得
				String[] fids = scopeTree.getAllFacilityIdList();
				
				for(int i=0; i<items.length; i++){
					for(int j=0; j<fids.length; j++){
						CollectedDataInfo data = getValue(
								fids[j], 
								items[i].getCollectorItemCode(), 
								items[i].getDeviceIndex()
						);
						
						// DBへ出力
						CalculatedDataDAO dao = new CalculatedDataDAO();
						dao.insert(collectorID, data);
					}
				}

				// 最終収集時刻を設定
				setLastCollectDate(new Date(scopeTree.getLastCollectTime()));
				
				// 収集回数をDBに書き込みます
				setCount(getCount()+1);
			}
		} catch (Exception e) {
			e.printStackTrace();
			m_log.error(e);
			// 状態を異常に変更
			this.setErrorStatus(EndStatusConstant.TYPE_ABNORMAL);
		}
		
		m_log.debug("storeCalcValue() end   : " + collectorID + "  " + collectorType);
	}
	
	/**
	 * 性能値を算出し閾値判定します。
	 * 
	 * @ejb.interface-method
	 *	view-type="both" 
	 */
	public void monitorCalcValue(){
		m_log.debug("monitorCalcValue() start : " + collectorID + "  " + collectorType);
		
		if(scopeTree == null || items == null || targetOID == null){
			m_log.debug("情報を失っています");
			return;
		}
		
		try{
			// MIB値を取得
			scopeTree.fetchMibValue(this.facilityID, this.targetOID, this.interval);
			
			// 性能管理閾値監視情報を取得
			MonitorPerfInfoHome home = JNDIConnectionManager.getMonitorPerfInfo();
			Collection mPerfInfos = home.findAll();
			
			Iterator itr = mPerfInfos.iterator();
			while(itr.hasNext()){
				MonitorPerfInfo monInfoLocal = (MonitorPerfInfo)itr.next();
				
				if(monInfoLocal.getCollectorId().equals(collectorID)){
					String monitorTypeId = monInfoLocal.getMonitorTypeId();
					String monitorId = monInfoLocal.getMonitorId();
					String itemCode = monInfoLocal.getItemCode();
					int deviceIndex = monInfoLocal.getDeviceIndex();
					
					// 対象ファシリティ(ノードもしくはスコープ)の閾値判定を実行する
					CollectedDataInfo data = getValue(this.facilityID, itemCode, deviceIndex);
					
					// 閾値判定を実行
					RunMonitorPerformance2 runMonitor = new RunMonitorPerformance2();
					runMonitor.run(monitorTypeId, monitorId, data);

					 // 監視対象ファシリティがスコープの場合は、スコープに含まれるノードへの処理を行う
					Repository rep = new Repository();
					if(!rep.isNode(this.facilityID)){
						// スコープに含まれるノードの閾値判定を実行
						// 全てのノードのIDを取得
						String[] nodeFids = scopeTree.getNodeIDList(this.facilityID);
						
						for(int j=0; j<nodeFids.length; j++){
							data = getValue(nodeFids[j], itemCode, deviceIndex);
							
							// 閾値判定を実行
							runMonitor = new RunMonitorPerformance2();
							runMonitor.run(monitorTypeId, monitorId, data);
						}
					}
				}
			}
			
			// 最終収集時刻を設定
			setLastCollectDate(new Date(scopeTree.getLastCollectTime()));
			
			// 収集回数をDBに書き込みます
			setCount(getCount()+1);
		} catch (Exception e) {
			m_log.error(e);
			e.printStackTrace();
		}
		
		m_log.debug("monitorCalcValue() end   : " + collectorID + "  " + collectorType);
	}
	
	/**
	 * 生存期間カウンタをリセットします。
	 *
	 */
	private void resetLifetimeCounter(){
		lifetimeCounter = 0;
	}
	
	
	/**
	 * 収集IDを取得します。
	 * 
	 * @return 収集ID
	 * 
	 * @ejb.persistence
	 * @ejb.pk-field 
	 * 
	 * @ejb.interface-method
	 *	view-type="both" 
	 */
	public String getCollectorID() {
		return collectorID;
	}
	
	/**
	 * 収集IDを設定します。
	 * @param collectorID 収集ID
	 */
	public void setCollectorID(String collectorID) {
		this.collectorID = collectorID;
	}
	
	/**
	 * 収集の種別を取得します。(リアルタイム収集もしくは実績収集)
	 * 
	 * @return 収集種別
	 * 
	 * @ejb.persistence
	 */
	public int getCollectorType() {
		return collectorType;
	}
	
	/**
	 * 収集の種別を設定します。(リアルタイム収集もしくは実績収集)
	 * 
	 * @return 収集種別
	 */
	public void setCollectorType(int collectorType) {
		this.collectorType = collectorType;
	}
	
	/**
	 * ファシリティIDを取得します。
	 * @return facilityID ファシリティID
	 * 
	 * @ejb.persistence 
	 */
	public String getFacilityID() {
		return facilityID;
	}
	
	/**
	 * ファシリティIDを設定します。
	 * @param facilityID ファシリティID
	 */
	public void setFacilityID(String facilityID) {
		m_log.debug("setFacilityID() start : " + collectorID);
		
		this.facilityID = facilityID;
		
		m_log.debug("setFacilityID() end   : " + collectorID);
	}
	
	/**
	 * 性能値算出用のファシリティツリー情報を再構築する
	 */
	public void updateScopeTree() {
		m_log.debug("updateScopeTree() start : " + collectorID);
		
		FacilityTreeItem tree = getFacilityTree();
		
		if(tree != null){
			// ファシリティツリー情報を再構築する
			this.scopeTree = new ScopeTree(tree);
		}
		
		m_log.debug("updateScopeTree() end   : " + collectorID);
	}
	
	
	/**
	 * ファシリティツリーを取得します。
	 * @return facilityTree ファシリティツリー
	 * 
	 * @ejb.interface-method
	 *  view-type="both"
	 * 
	 * @ejb.persistence 
	 */
	public FacilityTreeItem getFacilityTree() {
		m_log.debug("getFacilityTree() collector type : " + collectorType); 
		
		if(facilityID != null && 
				(collectorType == CollectorType.REALTIME || collectorType == CollectorType.MONITOR)){
			// リポジトリから取得
			// リポジトリの情報が変更されたなどの理由で指定のファシリティIDが存在しない場合 null が返る
			return new Repository().getFacilityTree(facilityID);
		} else if(collectorID != null && collectorType == CollectorType.RECORD){
			// DBからファシリティツリー情報を取得
			return new FacilityTreeDB().getFacilityTree(collectorID);
		} else {
			return null;
		}
	}
	
	/**
	 * 収集間隔を取得します。
	 * @return interval 収集間隔
	 *
	 * @ejb.interface-method
	 *  view-type="both"
	 * 
	 * @ejb.persistence 
	 */
	public int getInterval() {
		return interval;
	}
	
	/**
	 * 収集間隔を設定します。
	 * @param interval 収集間隔
	 */
	public void setInterval(int interval) {
		this.interval = interval;
	}
	
	/**
	 * 収集のラベルを取得します。
	 * @return label ラベル
	 * 
	 * @ejb.persistence 
	 */
	public String getLabel() {
		return label;
	}
	
	/**
	 * ラベルを設定します。
	 * @param label ラベル
	 */
	public void setLabel(String label) {
		this.label = label;
	}
	
	/**
	 * 収集期間を取得します。
	 * @return period 収集期間
	 * 
	 * @ejb.persistence 
	 */
	public int getPeriod() {
		return period;
	}
	
	/**
	 * 収集期間を設定します。
	 * @param period 収集期間
	 */
	public void setPeriod(int period) {
		this.period = period;
	}
	
	/**
	 * 収集回数を取得します。
	 * @return count 収集回数
	 * 
	 * @ejb.persistence 
	 */
	public int getCount() {
		return getCollectorStatus().getCount();
	}
	
	/**
	 * 収集回数を設定します。
	 * 
	 * @param count 収集回数
	 */
	public void setCount(int count) {
		getCollectorStatus().setCount(count);
	}
	
	/**
	 * 実行中のエラー状態を設定します。
	 * 
	 * @param status 実行中のエラー状態
	 */
	public void setErrorStatus(int status) {
		getCollectorStatus().setErrorStatus(status);
		
		int endStatus = getCollectorStatus().getEndStatus();
		
		// 現在までの状態より深刻な状態の場合は終了状態を変更する
		
		// 現在までの終了状態が"正常"で、状態が"警告"または"異常"に変化した場合
		if(endStatus == EndStatusConstant.TYPE_NORMAL &&
				(status == EndStatusConstant.TYPE_WARNING || 
						status == EndStatusConstant.TYPE_ABNORMAL)){
			getCollectorStatus().setEndStatus(status);
		}
		
		// 現在までの終了状態が"警告"で、状態が"異常"に変化した場合
		if(endStatus == EndStatusConstant.TYPE_WARNING &&
				status == EndStatusConstant.TYPE_ABNORMAL){
			getCollectorStatus().setEndStatus(status);
		}
		
		// 現在までの終了状態が"異常"以外で、状態が"異常"に変化した場合
		if(endStatus != EndStatusConstant.TYPE_ABNORMAL &&
				status == EndStatusConstant.TYPE_ABNORMAL){
			getCollectorStatus().setEndStatus(status);
		}
	}
	
	/**
	 * スコープパスを取得します。
	 * @return scopePath スコープパス
	 * 
	 * @ejb.persistence 
	 */
	public String getScopePath() {
		return scopePath;
	}
	
	/**
	 * スコープパスを設定します。
	 * @param scopePath スコープパス
	 */
	public void setScopePath(String scopePath) {
		this.scopePath = scopePath;
	}
	
	/**
	 * 収集開始日時を取得します。
	 * @return startDate 収集開始時刻(収集を開始していない場合はnullを返す)
	 *  @ejb.interface-method
	 *  view-type="both"
	 * @ejb.persistence 
	 */
	public Date getStartDate() {
		if(startTime != 0){
			return new Date(startTime);
		} else {
			return null;
		}
	}
	
	/**
	 * 収集開始日時を設定します。
	 * @param startTime 収集開始日時
	 * 
	 *  @ejb.interface-method
	 *  view-type="both"
	 *  
	 */
	public void setStartTime(long startTime) {
		this.startTime = startTime;
	}
	
	/**
	 * ステータスを取得します。
	 * @return status ステータス
	 * 
	 * @ejb.interface-method
	 *  view-type="both"
	 *  
	 * @ejb.persistence 
	 */
	public int getStatus() {
		//QuartzのSchedulerをルックアップ
		try {
			InitialContext iniCtx = JNDIConnectionManager.getInitialContext();
			Scheduler scheduler = (Scheduler)iniCtx.lookup(QuartzConstant.QUARTZ_NAME);
			
			// 登録されているジョブを取得する
			JobDetail job;
			try {
				job = scheduler.getJobDetail(collectorID, QuartzConstant.GROUP_COLLECT);
			} catch (SchedulerException e) {
				m_log.error(e);
				return CollectorRunStatus.ERROR;
			}
			
			// 登録されているトリガーを取得する
			Trigger trigger = null;
			try {
				trigger = scheduler.getTrigger(collectorID, QuartzConstant.GROUP_COLLECT);
			} catch (SchedulerException e) {
				m_log.error(e);
				return CollectorRunStatus.ERROR;
			}
			
			if(trigger == null){  // 収集実行ジョブが存在していない場合
				if(getStartDate() == null){
					return CollectorRunStatus.READY;
				} else {
					return CollectorRunStatus.FINISHED;
				}
			} else if(job.isDurable()){
				return CollectorRunStatus.RUNNING;
			} else {
				return CollectorRunStatus.SUSPEND;
			}
		} catch (NamingException e) {
			throw new EJBException(e);
		}
	}
		
	/**
	 * 収集終了時刻を取得します。
	 * @return 収集終了時刻
	 * 
	 * @ejb.persistence 
	 */
	public Date getStopDate() {
		if(stopTime == 0 || stopTime == Long.MAX_VALUE) {
			return null;  // 無制限の場合
		} else {
			return new Date(stopTime);
		}
	}
	
	/**
	 * 収集終了日時を設定します。
	 * @param stopTime 収集終了日時
	 */
	public void setStopTime(long stopTime) {
		this.stopTime = stopTime;
	}
	
	/**
	 * 実際に収集していた時間を返します。
	 * @return 収集時間(ミリ秒)
	 * 
	 * @ejb.persistence 
	 */
	public long getRealCollectPeriod() {
		Date lastCollect = getCollectorStatus().getLastCollectDate();
		if(lastCollect == null){
			return 0l;
		} else {
			return lastCollect.getTime() - startTime;
		}
	}
	
	private CollectorStatusLocal getCollectorStatus(){
		try {
			return CollectorStatusUtil.getLocalHome().findByPrimaryKey(
					new CollectorStatusPK(collectorID));
		} catch (FinderException e) {
			e.printStackTrace();
		} catch (NamingException e) {
			e.printStackTrace();
		}
		
		return null;
	}
	
	/**
	 * 収集終了時の状態を取得します。
	 * @return count 終了状態
	 * 
	 * @ejb.persistence 
	 */
	public int getEndStatus() {
		return getCollectorStatus().getEndStatus();
	}
	
	private void setLastCollectDate(Date date)
	{
		getCollectorStatus().setLastCollectDate(date);
	}
	
	/**
	 * 収集を続けるべきかどうかを判定します。
	 * このコレクターが指定の回数以上参照されていない場合は、falseを返します。
	 * 
	 * @return まだ収集を続ける場合はtrueを、終了すべき状態にある場合は、falseを返します。
	 * 
	 * @ejb.interface-method
	 *  view-type="both"
	 *  
	 **/
	public boolean checkLifetime(){
		if (MAX_LIFECOUNT >= lifetimeCounter){
			return true;
		} else {
			return false;
		}
	}
	
	/**
	 * アプリケーションログにログを出力
	 * 
	 * @param e 例外
	 */
	private void outputLog(String index, String[] messages) {
		AplLogger apllog = new AplLogger("PERF", "perf");
		apllog.put("SYS", index, messages);
	}
	
	// いずれは削除する予定
	/**
	 * 閾値監視フラグを取得します。
	 * @return monitorFlag 閾値監視フラグ
	 * 
	 * @ejb.persistence 
	 */
	public boolean isMonitorFlag() {
		return false;
	}

	/**
	 * 無期限収集用の保存期間情報を取得する。
	 * @return
	 * 	@ejb.interface-method
	 *  view-type="both"
	 *  @ejb.persistence 
	 */
	public int getPresavePeriod() {
		return presavePeriod;
	}
	/**
	 * 無期限収集用の保存期間情報をセットする。 
	 * @param presavePeriod
	 */
	public void setPresavePeriod(int presavePeriod) {
		this.presavePeriod = presavePeriod;
	}
	
	/**
	 * 性能値のマネージメントをおこないます。
	 * 
	 * @ejb.interface-method
	 *	view-type="both" 
	 */
	public void managePresave(Date startDate){

		CalculatedDataDAO dao = new CalculatedDataDAO();
		dao.deleteOverPresave(collectorID, startDate);
		int count = dao.recountFromDB(collectorID);
		if(count != 0){
			this.setCount(count);
		}
	}
	
}
