/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.repository.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.ArrayList;

import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.bean.Property;
import com.clustercontrol.repository.ejb.session.RepositoryController;
import com.clustercontrol.repository.ejb.session.RepositoryControllerBean;
import com.clustercontrol.repository.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;
import com.clustercontrol.util.PropertyUtil;

/**
 * 
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class GetNodeList {

    // ----- instance メソッド ----- //

    /**
     * 全てのノード一覧を返します。
     * 
     * @return ノード一覧
     */
    public ArrayList getAll() {
        RepositoryController repository = EjbConnectionManager
                .getConnectionManager().getRepositoryController();

        ArrayList records = null;
        try {
            records = repository.getNodeList();
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        } catch (FinderException e) {
        } catch (NamingException e) {
        }
        return records;
    }

    /**
     * propertyの条件にヒットするノードの一覧を返します。
     * 
     * @param property
     * @return ノード一覧
     */
    public ArrayList get(Property property) {
        PropertyUtil.deletePropertyDefine(property);

        RepositoryController repository = EjbConnectionManager
                .getConnectionManager().getRepositoryController();

        ArrayList records = null;
        try {
            records = repository.getNodeList(property);
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        } catch (FinderException e) {
        } catch (NamingException e) {
        }
        return records;
    }

    /**
     * 指定したスコープに属するノードの一覧を返します。
     * 
     * @param facilityId
     *            スコープのファシリティID
     * @return ノード一覧
     */
    public ArrayList get(String facilityId) {
        RepositoryController repository = EjbConnectionManager
                .getConnectionManager().getRepositoryController();

        ArrayList records = null;
        try {
            records = repository.getNodeList(facilityId,
                    RepositoryControllerBean.ONE_LEVEL);
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        } catch (FinderException e) {
        } catch (NamingException e) {
        }
        return records;
    }
}